@@ -3,7 +3,7 @@ import pytest
 
 class TestProduct:
     @pytest.mark.vcr
-    def test_product_get_details_valid(self, grocy, grocy_api_client):
+    def test_product_get_details_valid(self, grocy):
         product = grocy.product(10)
 
         assert product.name == "Cheese"
@@ -11,6 +11,16 @@ class TestProduct:
         assert len(product.barcodes) == 0
         assert product.product_group_id == 6
 
+    @pytest.mark.vcr
+    def test_product_no_barcodes(self, grocy):
+        stock = grocy.stock()
+        product = next(prod for prod in stock if prod.id == 2)
+
+        assert product.name == "Chocolate"
+        assert product.product_barcodes is not None
+        assert isinstance(product.product_barcodes, list)
+        assert len(product.product_barcodes) == 0
+
     @pytest.mark.vcr
     def test_product_get_details_non_existant(self, grocy):
         import requests
